Package: RMVL
Title: Mappable Vector Library for Handling Large Datasets
Version: 1.1.0.3
Authors@R: 
    person(given = "Vladimir",
           family = "Dergachev",
           role = c("aut", "cre"),
           email = "support@altumrete.com",
           comment = c(ORCID="https://orcid.org/0000-0003-4708-6625"))
Description: Mappable vector library provides convenient way to access large datasets. Use all of your data at once, with few limits. Memory mapped data can be shared between multiple R processes. Access speed depends on storage medium, so solid state drive is recommended, preferably with PCI Express (or M.2 nvme) interface or a fast network file system. The data is memory mapped into R and then accessed using usual R list and array subscription operators. Convenience functions are provided for merging, grouping and indexing large vectors and data.frames. The layout of underlying MVL files is optimized for large datasets. The vectors are stored to guarantee alignment for vector intrinsics after memory map. The package is built on top of libMVL, which can be used as a standalone C library. libMVL has simple C API making it easy to interchange datasets with outside programs. Large MVL datasets are distributed via Academic Torrents <https://academictorrents.com/collection/mvl-datasets>. 
URL: https://academictorrents.com/collection/mvl-datasets,
        https://github.com/volodya31415/RMVL,
        https://github.com/volodya31415/libMVL
License: LGPL-2.1
Depends: R (>= 3.5.0)
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-04-12 19:00:19 UTC; volodya
Author: Vladimir Dergachev [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4708-6625>)
Maintainer: Vladimir Dergachev <support@altumrete.com>
Repository: CRAN
Date/Publication: 2026-04-13 11:20:10 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 02:04:53 UTC; unix
Archs: RMVL.so.dSYM
