# Generated by roxygen2: do not edit by hand

S3method("$",MVL)
S3method("[",MVL)
S3method("[",MVL_OBJECT)
S3method("[",MVL_OFFSET)
S3method("[[",MVL_OBJECT)
S3method("[[",MVL_OFFSET)
S3method(dim,MVL_OBJECT)
S3method(length,MVL_OBJECT)
S3method(names,MVL)
S3method(names,MVL_OBJECT)
S3method(print,MVL)
S3method(print,MVL_INDEX)
S3method(print,MVL_OBJECT)
export("$.MVL")
export("[.MVL")
export("[.MVL_OBJECT")
export("[[.MVL_OBJECT")
export(mvl2R)
export(mvl_add_directory_entries)
export(mvl_class)
export(mvl_close)
export(mvl_compute_repeats)
export(mvl_extent_index_lapply)
export(mvl_find_matches)
export(mvl_fused_write_objects)
export(mvl_get_groups)
export(mvl_get_neighbors)
export(mvl_group)
export(mvl_group_lapply)
export(mvl_hash_vectors)
export(mvl_index_lapply)
export(mvl_indexed_copy)
export(mvl_inherits)
export(mvl_merge)
export(mvl_neighbors_lapply)
export(mvl_object_stats)
export(mvl_open)
export(mvl_order_vectors)
export(mvl_remap)
export(mvl_rewrite_vector)
export(mvl_start_write_vector)
export(mvl_status)
export(mvl_verify)
export(mvl_write_extent_index)
export(mvl_write_groups)
export(mvl_write_hash_vectors)
export(mvl_write_object)
export(mvl_write_serialized_object)
export(mvl_write_spatial_groups)
export(mvl_write_spatial_index1)
export(mvl_xlength)
useDynLib(RMVL , .registration=TRUE)
