% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RMVL.R
\name{mvl_status}
\alias{mvl_status}
\title{Return status of MVL package}
\usage{
mvl_status()
}
\value{
list of status values
}
\description{
Return status of MVL package
}
